# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SmsControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_sent_sms_message(self, sent_sms_id, **kwargs):  # noqa: E501
        """Delete sent SMS message.  # noqa: E501

        Delete a sent SMS message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sent_sms_message(sent_sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sent_sms_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_sent_sms_message_with_http_info(sent_sms_id, **kwargs)  # noqa: E501

    def delete_sent_sms_message_with_http_info(self, sent_sms_id, **kwargs):  # noqa: E501
        """Delete sent SMS message.  # noqa: E501

        Delete a sent SMS message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sent_sms_message_with_http_info(sent_sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sent_sms_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sent_sms_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sent_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sent_sms_id' is set
        if self.api_client.client_side_validation and ('sent_sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sent_sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sent_sms_id` when calling `delete_sent_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sent_sms_id' in local_var_params:
            path_params['sentSmsId'] = local_var_params['sent_sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/sent/{sentSmsId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sent_sms_messages(self, **kwargs):  # noqa: E501
        """Delete all sent SMS messages  # noqa: E501

        Delete all sent SMS messages or all messages for a given phone number  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sent_sms_messages(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_sent_sms_messages_with_http_info(**kwargs)  # noqa: E501

    def delete_sent_sms_messages_with_http_info(self, **kwargs):  # noqa: E501
        """Delete all sent SMS messages  # noqa: E501

        Delete all sent SMS messages or all messages for a given phone number  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sent_sms_messages_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone_number_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sent_sms_messages" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'phone_number_id' in local_var_params and local_var_params['phone_number_id'] is not None:  # noqa: E501
            query_params.append(('phoneNumberId', local_var_params['phone_number_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/sent', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sms_message(self, sms_id, **kwargs):  # noqa: E501
        """Delete SMS message.  # noqa: E501

        Delete an SMS message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_message(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_sms_message_with_http_info(sms_id, **kwargs)  # noqa: E501

    def delete_sms_message_with_http_info(self, sms_id, **kwargs):  # noqa: E501
        """Delete SMS message.  # noqa: E501

        Delete an SMS message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_message_with_http_info(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `delete_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sms_messages(self, **kwargs):  # noqa: E501
        """Delete all SMS messages  # noqa: E501

        Delete all SMS messages or all messages for a given phone number  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_messages(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_sms_messages_with_http_info(**kwargs)  # noqa: E501

    def delete_sms_messages_with_http_info(self, **kwargs):  # noqa: E501
        """Delete all SMS messages  # noqa: E501

        Delete all SMS messages or all messages for a given phone number  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_messages_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone_number_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sms_messages" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'phone_number_id' in local_var_params and local_var_params['phone_number_id'] is not None:  # noqa: E501
            query_params.append(('phoneNumberId', local_var_params['phone_number_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_sms_messages(self, **kwargs):  # noqa: E501
        """get_all_sms_messages  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_sms_messages(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number: Optional receiving phone number to filter SMS messages for
        :param int page: Optional page index in SMS list pagination
        :param int size: Optional page size in SMS list pagination. Maximum size is 100. Use page index and sort to page through larger results
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Optional filter SMSs received after given date time
        :param datetime before: Optional filter SMSs received before given date time
        :param str search: Optional search filter
        :param bool favourite: Optionally filter results for favourites only
        :param list[str] include: Optional list of IDs to include in result
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageSmsProjection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_all_sms_messages_with_http_info(**kwargs)  # noqa: E501

    def get_all_sms_messages_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_sms_messages  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_sms_messages_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number: Optional receiving phone number to filter SMS messages for
        :param int page: Optional page index in SMS list pagination
        :param int size: Optional page size in SMS list pagination. Maximum size is 100. Use page index and sort to page through larger results
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Optional filter SMSs received after given date time
        :param datetime before: Optional filter SMSs received before given date time
        :param str search: Optional search filter
        :param bool favourite: Optionally filter results for favourites only
        :param list[str] include: Optional list of IDs to include in result
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageSmsProjection, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone_number',
            'page',
            'size',
            'sort',
            'since',
            'before',
            'search',
            'favourite',
            'include'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_sms_messages" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_all_sms_messages`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'phone_number' in local_var_params and local_var_params['phone_number'] is not None:  # noqa: E501
            query_params.append(('phoneNumber', local_var_params['phone_number']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'search' in local_var_params and local_var_params['search'] is not None:  # noqa: E501
            query_params.append(('search', local_var_params['search']))  # noqa: E501
        if 'favourite' in local_var_params and local_var_params['favourite'] is not None:  # noqa: E501
            query_params.append(('favourite', local_var_params['favourite']))  # noqa: E501
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501
            collection_formats['include'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageSmsProjection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_reply_for_sms_message(self, sms_id, **kwargs):  # noqa: E501
        """Get reply for an SMS message  # noqa: E501

        Get reply for an SMS message.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_reply_for_sms_message(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ReplyForSms
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_reply_for_sms_message_with_http_info(sms_id, **kwargs)  # noqa: E501

    def get_reply_for_sms_message_with_http_info(self, sms_id, **kwargs):  # noqa: E501
        """Get reply for an SMS message  # noqa: E501

        Get reply for an SMS message.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_reply_for_sms_message_with_http_info(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ReplyForSms, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_reply_for_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `get_reply_for_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}/reply', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReplyForSms',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sent_sms_count(self, **kwargs):  # noqa: E501
        """Get sent SMS count  # noqa: E501

        Get number of sent SMS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CountDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sent_sms_count_with_http_info(**kwargs)  # noqa: E501

    def get_sent_sms_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get sent SMS count  # noqa: E501

        Get number of sent SMS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CountDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sent_sms_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/sent/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sent_sms_message(self, sent_sms_id, **kwargs):  # noqa: E501
        """Get sent SMS content including body. Expects sent SMS to exist by ID.  # noqa: E501

        Returns an SMS summary object with content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_message(sent_sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sent_sms_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SentSmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sent_sms_message_with_http_info(sent_sms_id, **kwargs)  # noqa: E501

    def get_sent_sms_message_with_http_info(self, sent_sms_id, **kwargs):  # noqa: E501
        """Get sent SMS content including body. Expects sent SMS to exist by ID.  # noqa: E501

        Returns an SMS summary object with content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_message_with_http_info(sent_sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sent_sms_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SentSmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sent_sms_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sent_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sent_sms_id' is set
        if self.api_client.client_side_validation and ('sent_sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sent_sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sent_sms_id` when calling `get_sent_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sent_sms_id' in local_var_params:
            path_params['sentSmsId'] = local_var_params['sent_sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/sent/{sentSmsId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SentSmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sent_sms_messages_paginated(self, **kwargs):  # noqa: E501
        """Get all SMS messages in all phone numbers in paginated form. .  # noqa: E501

        By default returns all SMS messages across all phone numbers sorted by ascending created at date. Responses are paginated. You can restrict results to a list of phone number IDs. You can also filter out read messages  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_messages_paginated(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number: Optional phone number to filter sent SMS messages for
        :param int page: Optional page index in SMS list pagination
        :param int size: Optional page size in SMS list pagination. Maximum size is 100. Use page index and sort to page through larger results
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Optional filter SMSs received after given date time
        :param datetime before: Optional filter SMSs received before given date time
        :param str search: Optional search filter
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageSentSmsProjection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sent_sms_messages_paginated_with_http_info(**kwargs)  # noqa: E501

    def get_sent_sms_messages_paginated_with_http_info(self, **kwargs):  # noqa: E501
        """Get all SMS messages in all phone numbers in paginated form. .  # noqa: E501

        By default returns all SMS messages across all phone numbers sorted by ascending created at date. Responses are paginated. You can restrict results to a list of phone number IDs. You can also filter out read messages  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sent_sms_messages_paginated_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone_number: Optional phone number to filter sent SMS messages for
        :param int page: Optional page index in SMS list pagination
        :param int size: Optional page size in SMS list pagination. Maximum size is 100. Use page index and sort to page through larger results
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Optional filter SMSs received after given date time
        :param datetime before: Optional filter SMSs received before given date time
        :param str search: Optional search filter
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageSentSmsProjection, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone_number',
            'page',
            'size',
            'sort',
            'since',
            'before',
            'search'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sent_sms_messages_paginated" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_sent_sms_messages_paginated`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'phone_number' in local_var_params and local_var_params['phone_number'] is not None:  # noqa: E501
            query_params.append(('phoneNumber', local_var_params['phone_number']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'search' in local_var_params and local_var_params['search'] is not None:  # noqa: E501
            query_params.append(('search', local_var_params['search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/sent', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageSentSmsProjection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sms_codes(self, sms_id, **kwargs):  # noqa: E501
        """Extract verification codes from an SMS  # noqa: E501

        Extract one-time passcodes and verification tokens from SMS body content. Deterministic `PATTERN` extraction is available now. Use method flags to control fallback behavior for QA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_codes(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: ID of SMS to extract codes from (required)
        :param ExtractCodesOptions extract_codes_options:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ExtractCodesResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sms_codes_with_http_info(sms_id, **kwargs)  # noqa: E501

    def get_sms_codes_with_http_info(self, sms_id, **kwargs):  # noqa: E501
        """Extract verification codes from an SMS  # noqa: E501

        Extract one-time passcodes and verification tokens from SMS body content. Deterministic `PATTERN` extraction is available now. Use method flags to control fallback behavior for QA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_codes_with_http_info(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: ID of SMS to extract codes from (required)
        :param ExtractCodesOptions extract_codes_options:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ExtractCodesResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id',
            'extract_codes_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sms_codes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `get_sms_codes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'extract_codes_options' in local_var_params:
            body_params = local_var_params['extract_codes_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}/codes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExtractCodesResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sms_count(self, **kwargs):  # noqa: E501
        """Get SMS count  # noqa: E501

        Get number of SMS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CountDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sms_count_with_http_info(**kwargs)  # noqa: E501

    def get_sms_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get SMS count  # noqa: E501

        Get number of SMS  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CountDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sms_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sms_message(self, sms_id, **kwargs):  # noqa: E501
        """Get SMS content including body. Expects SMS to exist by ID. For SMS that may not have arrived yet use the WaitForController.  # noqa: E501

        Returns a SMS summary object with content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_message(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sms_message_with_http_info(sms_id, **kwargs)  # noqa: E501

    def get_sms_message_with_http_info(self, sms_id, **kwargs):  # noqa: E501
        """Get SMS content including body. Expects SMS to exist by ID. For SMS that may not have arrived yet use the WaitForController.  # noqa: E501

        Returns a SMS summary object with content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_message_with_http_info(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `get_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_unread_sms_count(self, **kwargs):  # noqa: E501
        """Get unread SMS count  # noqa: E501

        Get number of SMS unread. Unread means has not been viewed in dashboard or returned in an email API response  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unread_sms_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UnreadCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_unread_sms_count_with_http_info(**kwargs)  # noqa: E501

    def get_unread_sms_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get unread SMS count  # noqa: E501

        Get number of SMS unread. Unread means has not been viewed in dashboard or returned in an email API response  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unread_sms_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UnreadCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_unread_sms_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/unreadCount', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UnreadCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mark_all_sms_as_read(self, **kwargs):  # noqa: E501
        """Mark all SMS messages as read or unread  # noqa: E501

        Sets read state for all SMS messages, optionally scoped to a single phone number. Use `read=false` to reset unread state in bulk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_all_sms_as_read(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool read:
        :param str phone_number_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.mark_all_sms_as_read_with_http_info(**kwargs)  # noqa: E501

    def mark_all_sms_as_read_with_http_info(self, **kwargs):  # noqa: E501
        """Mark all SMS messages as read or unread  # noqa: E501

        Sets read state for all SMS messages, optionally scoped to a single phone number. Use `read=false` to reset unread state in bulk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_all_sms_as_read_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool read:
        :param str phone_number_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'read',
            'phone_number_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mark_all_sms_as_read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'read' in local_var_params and local_var_params['read'] is not None:  # noqa: E501
            query_params.append(('read', local_var_params['read']))  # noqa: E501
        if 'phone_number_id' in local_var_params and local_var_params['phone_number_id'] is not None:  # noqa: E501
            query_params.append(('phoneNumberId', local_var_params['phone_number_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/read', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mark_sms_as_read(self, sms_id, **kwargs):  # noqa: E501
        """Mark an SMS as read or unread  # noqa: E501

        Sets read state for one SMS message. Useful when building custom inbox flows that need to restore unread state after inspection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_sms_as_read(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param bool read:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.mark_sms_as_read_with_http_info(sms_id, **kwargs)  # noqa: E501

    def mark_sms_as_read_with_http_info(self, sms_id, **kwargs):  # noqa: E501
        """Mark an SMS as read or unread  # noqa: E501

        Sets read state for one SMS message. Useful when building custom inbox flows that need to restore unread state after inspection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_sms_as_read_with_http_info(sms_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param bool read:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id',
            'read'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mark_sms_as_read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `mark_sms_as_read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []
        if 'read' in local_var_params and local_var_params['read'] is not None:  # noqa: E501
            query_params.append(('read', local_var_params['read']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}/read', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reply_to_sms_message(self, sms_id, sms_reply_options, **kwargs):  # noqa: E501
        """Send a reply to a received SMS message. Replies are sent from the receiving number.  # noqa: E501

        Reply to an SMS message.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reply_to_sms_message(sms_id, sms_reply_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param SmsReplyOptions sms_reply_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SentSmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.reply_to_sms_message_with_http_info(sms_id, sms_reply_options, **kwargs)  # noqa: E501

    def reply_to_sms_message_with_http_info(self, sms_id, sms_reply_options, **kwargs):  # noqa: E501
        """Send a reply to a received SMS message. Replies are sent from the receiving number.  # noqa: E501

        Reply to an SMS message.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reply_to_sms_message_with_http_info(sms_id, sms_reply_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: (required)
        :param SmsReplyOptions sms_reply_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SentSmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id',
            'sms_reply_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reply_to_sms_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `reply_to_sms_message`")  # noqa: E501
        # verify the required parameter 'sms_reply_options' is set
        if self.api_client.client_side_validation and ('sms_reply_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_reply_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_reply_options` when calling `reply_to_sms_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sms_reply_options' in local_var_params:
            body_params = local_var_params['sms_reply_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}/reply', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SentSmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_sms(self, sms_send_options, **kwargs):  # noqa: E501
        """send_sms  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms(sms_send_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SmsSendOptions sms_send_options: (required)
        :param str from_phone_number: Phone number to send from in E.164 format
        :param str from_phone_id: Phone number ID to send from in UUID form
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SentSmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.send_sms_with_http_info(sms_send_options, **kwargs)  # noqa: E501

    def send_sms_with_http_info(self, sms_send_options, **kwargs):  # noqa: E501
        """send_sms  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_with_http_info(sms_send_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SmsSendOptions sms_send_options: (required)
        :param str from_phone_number: Phone number to send from in E.164 format
        :param str from_phone_id: Phone number ID to send from in UUID form
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SentSmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_send_options',
            'from_phone_number',
            'from_phone_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_sms" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_send_options' is set
        if self.api_client.client_side_validation and ('sms_send_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_send_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_send_options` when calling `send_sms`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'from_phone_number' in local_var_params and local_var_params['from_phone_number'] is not None:  # noqa: E501
            query_params.append(('fromPhoneNumber', local_var_params['from_phone_number']))  # noqa: E501
        if 'from_phone_id' in local_var_params and local_var_params['from_phone_id'] is not None:  # noqa: E501
            query_params.append(('fromPhoneId', local_var_params['from_phone_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sms_send_options' in local_var_params:
            body_params = local_var_params['sms_send_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SentSmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_sms_favourited(self, sms_id, favourited, **kwargs):  # noqa: E501
        """set_sms_favourited  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sms_favourited(sms_id, favourited, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: ID of SMS to set favourite state (required)
        :param bool favourited: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SmsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.set_sms_favourited_with_http_info(sms_id, favourited, **kwargs)  # noqa: E501

    def set_sms_favourited_with_http_info(self, sms_id, favourited, **kwargs):  # noqa: E501
        """set_sms_favourited  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sms_favourited_with_http_info(sms_id, favourited, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sms_id: ID of SMS to set favourite state (required)
        :param bool favourited: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SmsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sms_id',
            'favourited'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_sms_favourited" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sms_id' is set
        if self.api_client.client_side_validation and ('sms_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sms_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sms_id` when calling `set_sms_favourited`")  # noqa: E501
        # verify the required parameter 'favourited' is set
        if self.api_client.client_side_validation and ('favourited' not in local_var_params or  # noqa: E501
                                                        local_var_params['favourited'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `favourited` when calling `set_sms_favourited`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sms_id' in local_var_params:
            path_params['smsId'] = local_var_params['sms_id']  # noqa: E501

        query_params = []
        if 'favourited' in local_var_params and local_var_params['favourited'] is not None:  # noqa: E501
            query_params.append(('favourited', local_var_params['favourited']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/sms/{smsId}/favourite', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SmsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateEmergencyAddressOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'customer_name': 'str',
        'address1': 'str',
        'city': 'str',
        'region': 'str',
        'postal_code': 'str',
        'iso_country_code': 'str',
        'display_name': 'str'
    }

    attribute_map = {
        'customer_name': 'customerName',
        'address1': 'address1',
        'city': 'city',
        'region': 'region',
        'postal_code': 'postalCode',
        'iso_country_code': 'isoCountryCode',
        'display_name': 'displayName'
    }

    def __init__(self, customer_name=None, address1=None, city=None, region=None, postal_code=None, iso_country_code=None, display_name=None, local_vars_configuration=None):  # noqa: E501
        """CreateEmergencyAddressOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._customer_name = None
        self._address1 = None
        self._city = None
        self._region = None
        self._postal_code = None
        self._iso_country_code = None
        self._display_name = None
        self.discriminator = None

        self.customer_name = customer_name
        self.address1 = address1
        self.city = city
        self.region = region
        self.postal_code = postal_code
        self.iso_country_code = iso_country_code
        if display_name is not None:
            self.display_name = display_name

    @property
    def customer_name(self):
        """Gets the customer_name of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The customer_name of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this CreateEmergencyAddressOptions.


        :param customer_name: The customer_name of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and customer_name is None:  # noqa: E501
            raise ValueError("Invalid value for `customer_name`, must not be `None`")  # noqa: E501

        self._customer_name = customer_name

    @property
    def address1(self):
        """Gets the address1 of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The address1 of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this CreateEmergencyAddressOptions.


        :param address1: The address1 of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address1 is None:  # noqa: E501
            raise ValueError("Invalid value for `address1`, must not be `None`")  # noqa: E501

        self._address1 = address1

    @property
    def city(self):
        """Gets the city of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The city of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this CreateEmergencyAddressOptions.


        :param city: The city of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and city is None:  # noqa: E501
            raise ValueError("Invalid value for `city`, must not be `None`")  # noqa: E501

        self._city = city

    @property
    def region(self):
        """Gets the region of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The region of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this CreateEmergencyAddressOptions.


        :param region: The region of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and region is None:  # noqa: E501
            raise ValueError("Invalid value for `region`, must not be `None`")  # noqa: E501

        self._region = region

    @property
    def postal_code(self):
        """Gets the postal_code of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The postal_code of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this CreateEmergencyAddressOptions.


        :param postal_code: The postal_code of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and postal_code is None:  # noqa: E501
            raise ValueError("Invalid value for `postal_code`, must not be `None`")  # noqa: E501

        self._postal_code = postal_code

    @property
    def iso_country_code(self):
        """Gets the iso_country_code of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The iso_country_code of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._iso_country_code

    @iso_country_code.setter
    def iso_country_code(self, iso_country_code):
        """Sets the iso_country_code of this CreateEmergencyAddressOptions.


        :param iso_country_code: The iso_country_code of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and iso_country_code is None:  # noqa: E501
            raise ValueError("Invalid value for `iso_country_code`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and iso_country_code not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `iso_country_code` ({0}), must be one of {1}"  # noqa: E501
                .format(iso_country_code, allowed_values)
            )

        self._iso_country_code = iso_country_code

    @property
    def display_name(self):
        """Gets the display_name of this CreateEmergencyAddressOptions.  # noqa: E501


        :return: The display_name of this CreateEmergencyAddressOptions.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateEmergencyAddressOptions.


        :param display_name: The display_name of this CreateEmergencyAddressOptions.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateEmergencyAddressOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateEmergencyAddressOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainRegionInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain_name': 'str',
        'verified': 'bool',
        'domain_type': 'str',
        'account_region': 'str',
        'creation_enabled': 'bool',
        'sending_enabled': 'bool',
        'active': 'bool'
    }

    attribute_map = {
        'domain_name': 'domainName',
        'verified': 'verified',
        'domain_type': 'domainType',
        'account_region': 'accountRegion',
        'creation_enabled': 'creationEnabled',
        'sending_enabled': 'sendingEnabled',
        'active': 'active'
    }

    def __init__(self, domain_name=None, verified=None, domain_type=None, account_region=None, creation_enabled=None, sending_enabled=None, active=None, local_vars_configuration=None):  # noqa: E501
        """DomainRegionInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain_name = None
        self._verified = None
        self._domain_type = None
        self._account_region = None
        self._creation_enabled = None
        self._sending_enabled = None
        self._active = None
        self.discriminator = None

        self.domain_name = domain_name
        self.verified = verified
        self.domain_type = domain_type
        self.account_region = account_region
        self.creation_enabled = creation_enabled
        self.sending_enabled = sending_enabled
        self.active = active

    @property
    def domain_name(self):
        """Gets the domain_name of this DomainRegionInformation.  # noqa: E501


        :return: The domain_name of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this DomainRegionInformation.


        :param domain_name: The domain_name of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain_name is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_name`, must not be `None`")  # noqa: E501

        self._domain_name = domain_name

    @property
    def verified(self):
        """Gets the verified of this DomainRegionInformation.  # noqa: E501


        :return: The verified of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        """Sets the verified of this DomainRegionInformation.


        :param verified: The verified of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and verified is None:  # noqa: E501
            raise ValueError("Invalid value for `verified`, must not be `None`")  # noqa: E501

        self._verified = verified

    @property
    def domain_type(self):
        """Gets the domain_type of this DomainRegionInformation.  # noqa: E501

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :return: The domain_type of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._domain_type

    @domain_type.setter
    def domain_type(self, domain_type):
        """Sets the domain_type of this DomainRegionInformation.

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :param domain_type: The domain_type of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain_type is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_type`, must not be `None`")  # noqa: E501
        allowed_values = ["HTTP_INBOX", "SMTP_DOMAIN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and domain_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `domain_type` ({0}), must be one of {1}"  # noqa: E501
                .format(domain_type, allowed_values)
            )

        self._domain_type = domain_type

    @property
    def account_region(self):
        """Gets the account_region of this DomainRegionInformation.  # noqa: E501


        :return: The account_region of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._account_region

    @account_region.setter
    def account_region(self, account_region):
        """Sets the account_region of this DomainRegionInformation.


        :param account_region: The account_region of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US_WEST_2_ACCOUNT_STAGING", "US_EAST_1_ACCOUNT_STAGING", "EU_WEST_1_ACCOUNT_STAGING", "US_WEST_2_ACCOUNT_SES_1", "EU_WEST_1_ACCOUNT_SES_1", "US_WEST_2_ACCOUNT_SES_2", "EU_WEST_1_ACCOUNT_SES_2", "US_WEST_2_ACCOUNT_BYTEWISE", "EU_WEST_1_ACCOUNT_BYTEWISE", "US_WEST_2", "EU_WEST_1", "US_EAST_1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account_region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account_region` ({0}), must be one of {1}"  # noqa: E501
                .format(account_region, allowed_values)
            )

        self._account_region = account_region

    @property
    def creation_enabled(self):
        """Gets the creation_enabled of this DomainRegionInformation.  # noqa: E501


        :return: The creation_enabled of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._creation_enabled

    @creation_enabled.setter
    def creation_enabled(self, creation_enabled):
        """Sets the creation_enabled of this DomainRegionInformation.


        :param creation_enabled: The creation_enabled of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and creation_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `creation_enabled`, must not be `None`")  # noqa: E501

        self._creation_enabled = creation_enabled

    @property
    def sending_enabled(self):
        """Gets the sending_enabled of this DomainRegionInformation.  # noqa: E501


        :return: The sending_enabled of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._sending_enabled

    @sending_enabled.setter
    def sending_enabled(self, sending_enabled):
        """Sets the sending_enabled of this DomainRegionInformation.


        :param sending_enabled: The sending_enabled of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and sending_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `sending_enabled`, must not be `None`")  # noqa: E501

        self._sending_enabled = sending_enabled

    @property
    def active(self):
        """Gets the active of this DomainRegionInformation.  # noqa: E501


        :return: The active of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this DomainRegionInformation.


        :param active: The active of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and active is None:  # noqa: E501
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainRegionInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainRegionInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneSmsPrepaidCreditDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'phone_country': 'str',
        '_global': 'bool',
        'remaining_credits': 'int',
        'initial_credits': 'int',
        'sent_multiplier': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'phone_country': 'phoneCountry',
        '_global': 'global',
        'remaining_credits': 'remainingCredits',
        'initial_credits': 'initialCredits',
        'sent_multiplier': 'sentMultiplier',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, phone_country=None, _global=None, remaining_credits=None, initial_credits=None, sent_multiplier=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """PhoneSmsPrepaidCreditDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._phone_country = None
        self.__global = None
        self._remaining_credits = None
        self._initial_credits = None
        self._sent_multiplier = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.phone_country = phone_country
        self._global = _global
        self.remaining_credits = remaining_credits
        self.initial_credits = initial_credits
        self.sent_multiplier = sent_multiplier
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The id of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneSmsPrepaidCreditDto.


        :param id: The id of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501

        Null means the balance is global for the account rather than country-specific.  # noqa: E501

        :return: The phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneSmsPrepaidCreditDto.

        Null means the balance is global for the account rather than country-specific.  # noqa: E501

        :param phone_country: The phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def _global(self):
        """Gets the _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: bool
        """
        return self.__global

    @_global.setter
    def _global(self, _global):
        """Sets the _global of this PhoneSmsPrepaidCreditDto.


        :param _global: The _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and _global is None:  # noqa: E501
            raise ValueError("Invalid value for `_global`, must not be `None`")  # noqa: E501

        self.__global = _global

    @property
    def remaining_credits(self):
        """Gets the remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._remaining_credits

    @remaining_credits.setter
    def remaining_credits(self, remaining_credits):
        """Sets the remaining_credits of this PhoneSmsPrepaidCreditDto.


        :param remaining_credits: The remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and remaining_credits is None:  # noqa: E501
            raise ValueError("Invalid value for `remaining_credits`, must not be `None`")  # noqa: E501

        self._remaining_credits = remaining_credits

    @property
    def initial_credits(self):
        """Gets the initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._initial_credits

    @initial_credits.setter
    def initial_credits(self, initial_credits):
        """Sets the initial_credits of this PhoneSmsPrepaidCreditDto.


        :param initial_credits: The initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and initial_credits is None:  # noqa: E501
            raise ValueError("Invalid value for `initial_credits`, must not be `None`")  # noqa: E501

        self._initial_credits = initial_credits

    @property
    def sent_multiplier(self):
        """Gets the sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._sent_multiplier

    @sent_multiplier.setter
    def sent_multiplier(self, sent_multiplier):
        """Sets the sent_multiplier of this PhoneSmsPrepaidCreditDto.


        :param sent_multiplier: The sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and sent_multiplier is None:  # noqa: E501
            raise ValueError("Invalid value for `sent_multiplier`, must not be `None`")  # noqa: E501

        self._sent_multiplier = sent_multiplier

    @property
    def created_at(self):
        """Gets the created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneSmsPrepaidCreditDto.


        :param created_at: The created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhoneSmsPrepaidCreditDto.


        :param updated_at: The updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneSmsPrepaidCreditDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneSmsPrepaidCreditDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CancelDevicePreviewRunResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'run': 'DevicePreviewRunDto',
        'remote_cancel_attempted': 'bool',
        'remote_cancel_accepted': 'bool',
        'warning': 'str'
    }

    attribute_map = {
        'run': 'run',
        'remote_cancel_attempted': 'remoteCancelAttempted',
        'remote_cancel_accepted': 'remoteCancelAccepted',
        'warning': 'warning'
    }

    def __init__(self, run=None, remote_cancel_attempted=None, remote_cancel_accepted=None, warning=None, local_vars_configuration=None):  # noqa: E501
        """CancelDevicePreviewRunResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._run = None
        self._remote_cancel_attempted = None
        self._remote_cancel_accepted = None
        self._warning = None
        self.discriminator = None

        self.run = run
        self.remote_cancel_attempted = remote_cancel_attempted
        self.remote_cancel_accepted = remote_cancel_accepted
        if warning is not None:
            self.warning = warning

    @property
    def run(self):
        """Gets the run of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The run of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: DevicePreviewRunDto
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this CancelDevicePreviewRunResult.


        :param run: The run of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: DevicePreviewRunDto
        """
        if self.local_vars_configuration.client_side_validation and run is None:  # noqa: E501
            raise ValueError("Invalid value for `run`, must not be `None`")  # noqa: E501

        self._run = run

    @property
    def remote_cancel_attempted(self):
        """Gets the remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: bool
        """
        return self._remote_cancel_attempted

    @remote_cancel_attempted.setter
    def remote_cancel_attempted(self, remote_cancel_attempted):
        """Sets the remote_cancel_attempted of this CancelDevicePreviewRunResult.


        :param remote_cancel_attempted: The remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and remote_cancel_attempted is None:  # noqa: E501
            raise ValueError("Invalid value for `remote_cancel_attempted`, must not be `None`")  # noqa: E501

        self._remote_cancel_attempted = remote_cancel_attempted

    @property
    def remote_cancel_accepted(self):
        """Gets the remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: bool
        """
        return self._remote_cancel_accepted

    @remote_cancel_accepted.setter
    def remote_cancel_accepted(self, remote_cancel_accepted):
        """Sets the remote_cancel_accepted of this CancelDevicePreviewRunResult.


        :param remote_cancel_accepted: The remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and remote_cancel_accepted is None:  # noqa: E501
            raise ValueError("Invalid value for `remote_cancel_accepted`, must not be `None`")  # noqa: E501

        self._remote_cancel_accepted = remote_cancel_accepted

    @property
    def warning(self):
        """Gets the warning of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The warning of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this CancelDevicePreviewRunResult.


        :param warning: The warning of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: str
        """

        self._warning = warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CancelDevicePreviewRunResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CancelDevicePreviewRunResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.domain_monitor_summary_dto import DomainMonitorSummaryDto  # noqa: E501
from mailslurp_client.rest import ApiException

class TestDomainMonitorSummaryDto(unittest.TestCase):
    """DomainMonitorSummaryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DomainMonitorSummaryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.domain_monitor_summary_dto.DomainMonitorSummaryDto()  # noqa: E501
        if include_optional :
            return DomainMonitorSummaryDto(
                monitor = mailslurp_client.models.domain_monitor_dto.DomainMonitorDto(
                    id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    name = '0', 
                    interval_seconds = 56, 
                    enabled = True, 
                    scheduling_enabled = True, 
                    last_status = 'HEALTHY', 
                    health_score = 56, 
                    last_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    next_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                    id = '0', 
                    monitor_id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    status = 'HEALTHY', 
                    trigger_source = 'API', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf_ok = True, 
                    dmarc_ok = True, 
                    dmarc_enforced = True, 
                    mx_ok = True, 
                    insights = [
                        '0'
                        ], 
                    error_message = '0', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                insights = mailslurp_client.models.domain_monitor_insights_dto.DomainMonitorInsightsDto(
                    monitor_id = '0', 
                    since = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    total_runs = 56, 
                    healthy_runs = 56, 
                    degraded_runs = 56, 
                    critical_runs = 56, 
                    failed_runs = 56, 
                    success_rate = 1.337, 
                    average_health_score = 1.337, 
                    current_healthy_streak = 56, 
                    best_healthy_streak = 56, 
                    good_performance_signals = [
                        '0'
                        ], 
                    attention_signals = [
                        '0'
                        ], 
                    top_findings = [
                        '0'
                        ], 
                    latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                        id = '0', 
                        monitor_id = '0', 
                        user_id = '0', 
                        domain = '0', 
                        status = 'HEALTHY', 
                        trigger_source = 'API', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        spf_ok = True, 
                        dmarc_ok = True, 
                        dmarc_enforced = True, 
                        mx_ok = True, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                auth_stack = mailslurp_client.models.check_email_auth_stack_results.CheckEmailAuthStackResults(
                    domain = '0', 
                    status = 'HEALTHY', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                        valid = True, 
                        host = '0', 
                        record = '0', 
                        flattened_record = '0', 
                        lookup_count = 56, 
                        mechanisms = [
                            mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                                kind = '0', 
                                value = '0', 
                                qualifier = '0', )
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                        valid = True, 
                        queried_name = '0', 
                        selector = '0', 
                        record = '0', 
                        algorithm = '0', 
                        key_length = 56, 
                        checked_names = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        well_known_query = '0', 
                        well_known_present = True, 
                        well_known_value = '0', 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    insights = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], )
            )
        else :
            return DomainMonitorSummaryDto(
                monitor = mailslurp_client.models.domain_monitor_dto.DomainMonitorDto(
                    id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    name = '0', 
                    interval_seconds = 56, 
                    enabled = True, 
                    scheduling_enabled = True, 
                    last_status = 'HEALTHY', 
                    health_score = 56, 
                    last_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    next_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                insights = mailslurp_client.models.domain_monitor_insights_dto.DomainMonitorInsightsDto(
                    monitor_id = '0', 
                    since = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    total_runs = 56, 
                    healthy_runs = 56, 
                    degraded_runs = 56, 
                    critical_runs = 56, 
                    failed_runs = 56, 
                    success_rate = 1.337, 
                    average_health_score = 1.337, 
                    current_healthy_streak = 56, 
                    best_healthy_streak = 56, 
                    good_performance_signals = [
                        '0'
                        ], 
                    attention_signals = [
                        '0'
                        ], 
                    top_findings = [
                        '0'
                        ], 
                    latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                        id = '0', 
                        monitor_id = '0', 
                        user_id = '0', 
                        domain = '0', 
                        status = 'HEALTHY', 
                        trigger_source = 'API', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        spf_ok = True, 
                        dmarc_ok = True, 
                        dmarc_enforced = True, 
                        mx_ok = True, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                auth_stack = mailslurp_client.models.check_email_auth_stack_results.CheckEmailAuthStackResults(
                    domain = '0', 
                    status = 'HEALTHY', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                        valid = True, 
                        host = '0', 
                        record = '0', 
                        flattened_record = '0', 
                        lookup_count = 56, 
                        mechanisms = [
                            mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                                kind = '0', 
                                value = '0', 
                                qualifier = '0', )
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                        valid = True, 
                        queried_name = '0', 
                        selector = '0', 
                        record = '0', 
                        algorithm = '0', 
                        key_length = 56, 
                        checked_names = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        well_known_query = '0', 
                        well_known_present = True, 
                        well_known_value = '0', 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    insights = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ),
        )

    def testDomainMonitorSummaryDto(self):
        """Test DomainMonitorSummaryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractCodesOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method': 'str',
        'allow_fallback': 'bool',
        'min_length': 'int',
        'max_length': 'int',
        'max_candidates': 'int',
        'custom_patterns': 'list[str]'
    }

    attribute_map = {
        'method': 'method',
        'allow_fallback': 'allowFallback',
        'min_length': 'minLength',
        'max_length': 'maxLength',
        'max_candidates': 'maxCandidates',
        'custom_patterns': 'customPatterns'
    }

    def __init__(self, method=None, allow_fallback=True, min_length=4, max_length=10, max_candidates=5, custom_patterns=None, local_vars_configuration=None):  # noqa: E501
        """ExtractCodesOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._method = None
        self._allow_fallback = None
        self._min_length = None
        self._max_length = None
        self._max_candidates = None
        self._custom_patterns = None
        self.discriminator = None

        self.method = method
        if allow_fallback is not None:
            self.allow_fallback = allow_fallback
        if min_length is not None:
            self.min_length = min_length
        if max_length is not None:
            self.max_length = max_length
        if max_candidates is not None:
            self.max_candidates = max_candidates
        self.custom_patterns = custom_patterns

    @property
    def method(self):
        """Gets the method of this ExtractCodesOptions.  # noqa: E501

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :return: The method of this ExtractCodesOptions.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this ExtractCodesOptions.

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :param method: The method of this ExtractCodesOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "PATTERN", "LLM", "OCR", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def allow_fallback(self):
        """Gets the allow_fallback of this ExtractCodesOptions.  # noqa: E501

        Allow fallback to deterministic pattern extraction when the selected method is unavailable.  # noqa: E501

        :return: The allow_fallback of this ExtractCodesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._allow_fallback

    @allow_fallback.setter
    def allow_fallback(self, allow_fallback):
        """Sets the allow_fallback of this ExtractCodesOptions.

        Allow fallback to deterministic pattern extraction when the selected method is unavailable.  # noqa: E501

        :param allow_fallback: The allow_fallback of this ExtractCodesOptions.  # noqa: E501
        :type: bool
        """

        self._allow_fallback = allow_fallback

    @property
    def min_length(self):
        """Gets the min_length of this ExtractCodesOptions.  # noqa: E501

        Minimum code length to consider. Typical OTP values are between 4 and 8 characters.  # noqa: E501

        :return: The min_length of this ExtractCodesOptions.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this ExtractCodesOptions.

        Minimum code length to consider. Typical OTP values are between 4 and 8 characters.  # noqa: E501

        :param min_length: The min_length of this ExtractCodesOptions.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    @property
    def max_length(self):
        """Gets the max_length of this ExtractCodesOptions.  # noqa: E501

        Maximum code length to consider.  # noqa: E501

        :return: The max_length of this ExtractCodesOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this ExtractCodesOptions.

        Maximum code length to consider.  # noqa: E501

        :param max_length: The max_length of this ExtractCodesOptions.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def max_candidates(self):
        """Gets the max_candidates of this ExtractCodesOptions.  # noqa: E501

        Maximum number of code candidates to return. Best candidate is also returned separately.  # noqa: E501

        :return: The max_candidates of this ExtractCodesOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_candidates

    @max_candidates.setter
    def max_candidates(self, max_candidates):
        """Sets the max_candidates of this ExtractCodesOptions.

        Maximum number of code candidates to return. Best candidate is also returned separately.  # noqa: E501

        :param max_candidates: The max_candidates of this ExtractCodesOptions.  # noqa: E501
        :type: int
        """

        self._max_candidates = max_candidates

    @property
    def custom_patterns(self):
        """Gets the custom_patterns of this ExtractCodesOptions.  # noqa: E501

        Optional custom regex patterns for code extraction. Each pattern should have either one capture group for the code or match the full code directly.  # noqa: E501

        :return: The custom_patterns of this ExtractCodesOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._custom_patterns

    @custom_patterns.setter
    def custom_patterns(self, custom_patterns):
        """Sets the custom_patterns of this ExtractCodesOptions.

        Optional custom regex patterns for code extraction. Each pattern should have either one capture group for the code or match the full code directly.  # noqa: E501

        :param custom_patterns: The custom_patterns of this ExtractCodesOptions.  # noqa: E501
        :type: list[str]
        """

        self._custom_patterns = custom_patterns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractCodesOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractCodesOptions):
            return True

        return self.to_dict() != other.to_dict()
